==> luhn-validator-1.1.2.tar.gz: luhn-validator-1.1.2/CHANGELOG.md <==
# Changelog

The format is based on [semantic versioning] and [pre-release versioning] schemes 
recommended by the Python Packaging Authority (PPA).

[semantic versioning]: https://packaging.python.org/guides/distributing-packages-using-setuptools/#semantic-versioning-preferred
[pre-release versioning]: https://packaging.python.org/guides/distributing-packages-using-setuptools/#pre-release-versioning

## 1.1.2 (2022-01-19)

- Improved type hints for `number` and `prefix` arguments.
- Improved handling of numbers containing hyphens or spaces.
- Updated documentation, tests, and usage examples.

## 1.1.1 (2021-10-29)

- Improved docstrings and package metadata.
- Improved usage examples.

## 1.1.0 (2021-10-20)

- Renamed the project to `luhn-validator` for more generic use.
- Changed `number` parameter of `validate` function to accept integers only.
- Added `length` and `prefix` parameters to `validate` function.
- Updated documentation and tests.
- Updated packaging configuration files and local development workflow.

## 1.0.7 (2021-10-18)

- Deprecated `saudi-id-validator` in favor of the new name.

## 1.0.6 (2021-03-18)

- Fixed the package homepage URL ([#2](https://github.com/dralshehri/luhn-validator/pull/2)).
- Updated CI tests to include recent python versions.

## 1.0.5 (2019-06-05)

- Added params to docstrings.
- Fixed a typo in README.

## 1.0.4 (2019-05-27)

- Updated README.

## 1.0.3 (2019-05-22)

- Updated usage example.
- Updated README badges.
- Removed LICENSE file extension.

## 1.0.2 (2018-12-06)

- Improved README content.

## 1.0.1 (2018-11-18)

- Fixed some typos in README file.

## 1.0.0 (2018-11-18)

- First release.

==> luhn-validator-1.1.3.tar.gz: luhn-validator-1.1.3/CHANGELOG.md <==
# Changelog

The format is based on [semantic versioning] and [pre-release versioning] schemes 
recommended by the Python Packaging Authority (PPA).

[semantic versioning]: https://packaging.python.org/guides/distributing-packages-using-setuptools/#semantic-versioning-preferred
[pre-release versioning]: https://packaging.python.org/guides/distributing-packages-using-setuptools/#pre-release-versioning

## 1.1.3 (2022-01-31)

- Changed type hints for `number` and `prefix` arguments to prefer strings.
- Changed GitHub username to @mhalshehri and updated related links.
- Updated development workflows and configurations.

## 1.1.2 (2022-01-19)

- Improved type hints for `number` and `prefix` arguments.
- Improved handling of numbers containing hyphens or spaces.
- Updated documentation, tests, and usage examples.

## 1.1.1 (2021-10-29)

- Improved docstrings and package metadata.
- Improved usage examples.

## 1.1.0 (2021-10-20)

- Renamed the project to `luhn-validator` for more generic use.
- Changed `number` parameter of `validate` function to accept integers only.
- Added `length` and `prefix` parameters to `validate` function.
- Updated documentation and tests.
- Updated packaging configuration files and local development workflow.

## 1.0.7 (2021-10-18)

- Deprecated `saudi-id-validator` in favor of the new name.

## 1.0.6 (2021-03-18)

- Fixed the package homepage URL ([#2](https://github.com/mhalshehri/luhn-validator/pull/2)).
- Updated CI tests to include recent python versions.

## 1.0.5 (2019-06-05)

- Added params to docstrings.
- Fixed a typo in README.

## 1.0.4 (2019-05-27)

- Updated README.

## 1.0.3 (2019-05-22)

- Updated usage example.
- Updated README badges.
- Removed LICENSE file extension.

## 1.0.2 (2018-12-06)

- Improved README content.

## 1.0.1 (2018-11-18)

- Fixed some typos in README file.

## 1.0.0 (2018-11-18)

- First release.
